#
# spec file for package perl-Params-ValidationCompiler
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Params-ValidationCompiler
Name:           perl-Params-ValidationCompiler
Version:        0.31
Release:        1.8
License:        Artistic-2.0
Summary:        Build an optimized subroutine parameter validator once, use it forever
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/D/DR/DROLSKY/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Eval::Closure)
BuildRequires:  perl(Exception::Class)
BuildRequires:  perl(List::Util) >= 1.29
BuildRequires:  perl(Specio) >= 0.14
BuildRequires:  perl(Test2::Plugin::NoWarnings)
BuildRequires:  perl(Test2::Require::Module)
BuildRequires:  perl(Test2::V0)
BuildRequires:  perl(Test::More) >= 1.302015
BuildRequires:  perl(Test::Without::Module)
Requires:       perl(Eval::Closure)
Requires:       perl(Exception::Class)
Requires:       perl(List::Util) >= 1.29
Recommends:     perl(Class::XSAccessor) >= 1.17
Recommends:     perl(Sub::Util) >= 1.40
%{perl_requires}

%description
This module creates a customized, highly efficient parameter checking
subroutine. It can handle named or positional parameters, and can return
the parameters as key/value pairs or a list of values.

In addition to type checks, it also supports parameter defaults, optional
parameters, and extra "slurpy" parameters.

%prep
%autosetup  -n %{cpan_name}-%{version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CODE_OF_CONDUCT.md CONTRIBUTING.md README.md test-matrix.als
%license LICENSE

%changelog
* Tue Feb 14 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.31
  see /usr/share/doc/packages/perl-Params-ValidationCompiler/Changes
  0.31     2023-01-06
  - Require Class::XSAccessor 1.17+ when trying to load it. Earlier versions
    cause test failures. Reported by David Cantrell. GH #27.
* Wed Aug  1 2018 coolo@suse.com
- updated to 0.30
  see /usr/share/doc/packages/perl-Params-ValidationCompiler/Changes
  0.30     2018-07-31
  - Tweaked the POD formatting so that the table of contents generated by
    MetaCPAN is more useful.
  0.29     2018-07-31
  - Make Class::XSAccessor a recommended dep, not a required one.
  0.28     2018-07-31
  - Added a new option for named params, "return_object". This causes the
    validation sub to return an object with methods for each param rather than a
    hashref. This is a great way to avoid typos in hash keys. This idea (and
    some of the implementation) was shamelessly stolen from Toby Inkster's
    Type::Params module.
* Mon Feb 12 2018 coolo@suse.com
- updated to 0.27
  see /usr/share/doc/packages/perl-Params-ValidationCompiler/Changes
  0.27     2018-02-11
  - Fixed a bug with inlining Moose types. If a type's parent needed environment
    variables those would not get closed over. Reported by Mark Fowler. GH #22.
  - Added a debug option to dump the source of the subroutine before it is
    eval'd.
* Fri Dec  8 2017 coolo@suse.com
- updated to 0.26
  see /usr/share/doc/packages/perl-Params-ValidationCompiler/Changes
  0.26     2017-11-28
  - The exceptions.t test would fail if Sub::Util was not installed. Reported by
    Paul Howarth. GH #19.
  - Fix test failures on Windows. GH #20.
* Fri Nov 24 2017 coolo@suse.com
- updated to 0.25
  see /usr/share/doc/packages/perl-Params-ValidationCompiler/Changes
  0.25     2017-11-23
  - All exceptions now include a stack trace by default when treated as a
    string. This makes finding where validation failed a lot easier. Fixes GH
    [#18].
  - The name for a subroutine is now used in some exception messages, even if
    Sub::Util cannot be installed.
* Wed May 31 2017 coolo@suse.com
- updated to 0.24
  see /usr/share/doc/packages/perl-Params-ValidationCompiler/Changes
  0.24     2017-04-08
  - The source_for() exported by Params::ValidationCompiler did not work at
    all. Reported by Diab Jerius. GH #16.
  0.23     2017-01-23
  - Trying to create a validator for positional parameters where a required
    param came after one with a default did not throw an exception.
  - A positional params validator with a slurpy type which had coercions did not
    return the coerced values. It returned the original values instead.
* Wed Jan 11 2017 coolo@suse.com
- initial package 0.22
  * created by cpanspec 1.78.08
